<?php
/**
 * Plugin settings markup
 */

// Enable xmas mood tooltip
$xmasmusic_enable_tooltip = get_option( 'xmasmusic_enable_tooltip' ) ?: '';

// Enable player on all pages
$xmasmusic_enable_player = get_option( 'default_play', 'true' );

// Background color of player
$button_background = esc_attr( get_option( 'button_bg' ) ) ?: '#ff0000';

// Color of play/pause icon
$icon_color = esc_attr( get_option( 'button_color' ) ) ?: '#ffffff';
?>

<div class="wrap hide-notices">
	<!-- Empty h2 for the admin notices view -->
	<h2></h2>

	<div class="christmas-music-settings">

		<div class="christmas-music-settings-main">

			<div class="christmas-music-settings-top">
				<h1><?php echo __( 'Christmas Music Settings', 'christmas-music' ); ?></h1>
				<a class="christmas-music-settings-pro-link" href="https://xmasmusicwp.com/" target="_blank">
				<?php echo __( 'Get PRO', 'christmas-music' ); ?>
					<img src="<?php echo XMAS_MUSIC_DIR_URL . 'admin/images/arrow-right.svg'; ?>" alt="icon" />
				</a>
				<div class="christmas-music-settings-logo-wrapper">
					<img src="<?php echo XMAS_MUSIC_DIR_URL . 'admin/images/christmas-music-logo.svg'; ?>" alt="Christmas Music Logo" />
					<div class="christmas-music-settings-edition"></div>
				</div>
			</div>

			<form method="post" action="options.php">
				<?php settings_fields( 'xmasmusic-plugin-settings-group' ); ?>
				<?php do_settings_sections( 'xmasmusic-plugin-settings-group' ); ?>

				<h2><?php echo __( 'General Options', 'christmas-music' ); ?></h2>
				<hr>
				<div class="christmas-music-settings-group">
					<div class="christmas-music-setting">
						<label class="christmas-music-checkbox-setting">
							<input type="checkbox" name="xmasmusic_enable_tooltip" value="true" <?php checked( 'true', $xmasmusic_enable_tooltip ); ?> />
							<div></div>
							<span><?php echo __( 'Add "Enable Xmas Mood" tooltip', 'christmas-music' ); ?></button>
						</label>
						<p class="christmas-music-setting-description"><?php echo __( "Some browsers don't allow autoplay on the first visit (before any user interaction happens), we added this feature to bring our play button to visitor's attention when that limitation happens.", 'christmas-music' ); ?></p>
					</div>

					<div class="christmas-music-setting">
						<label class="christmas-music-checkbox-setting">
							<input type="checkbox" name="default_play" value="true" <?php checked( 'true', $xmasmusic_enable_player ); ?> />
							<div></div>
							<span><?php echo __( 'Play on all pages (entire website)', 'christmas-music' ); ?></button>
						</label>
						<p class="christmas-music-setting-description"><?php echo __( 'If unchecked, you can add Christmas Music presence to any page or post or custom post type individually (go to the indiviudal page/post/cpt, you’ll find the settings at the top of the right sidebar)', 'christmas-music' ); ?></p>
					</div>

					<div class="christmas-music-setting xmas-pro-overlay">
						<p class="christmas-music-setting-label"><?php echo __( 'Replace music with your own MP3 or WAV', 'christmas-music' ); ?></p>
						<label class="christmas-music-file-setting">
							<input type="file" name="xmasmusic_file" accept=".mp3, .wav" />
							<span><?php echo __( 'Choose File', 'christmas-music' ); ?></span>
						</label>
						<p class="christmas-music-setting-description"><?php echo __( 'Format "WAV" is currently not supported in IE and Edge browsers', 'christmas-music' ); ?></p>
					</div>

					<div class="christmas-music-setting xmas-pro-overlay">
						<p class="christmas-music-setting-label"><?php echo __( 'Volume level', 'christmas-music' ); ?></p>
						<div class="christmas-music-volume-setting">
							<img src="<?php echo XMAS_MUSIC_DIR_URL . 'admin/images/volume.svg'; ?>" alt="icon" />
							<input class="christmas-music-range-setting" type="range" name="xmasmusic_volume" min="0" max="100" step="1" value="30" />
							<div class="christmas-music-volume-value"><span>30</span>%</div>
						</div>
					</div>

					<div class="christmas-music-setting xmas-pro-overlay">
						<label class="christmas-music-checkbox-setting">
							<input type="checkbox" name="xmasmusic_autoplay" value="true" checked />
							<div></div>
							<span><?php echo __( 'Autoplay', 'christmas-music' ); ?></button>
						</label>
						<p class="christmas-music-setting-description"><?php echo __( 'If unchecked, audio will not play until visitor clicks the "play" button', 'christmas-music' ); ?></p>
					</div>
				</div>
				<hr>


				<h2><?php echo __( 'Styling Options', 'christmas-music' ); ?></h2>
				<hr>
				<div class="christmas-music-settings-group">
					<div class="christmas-music-setting xmas-pro-overlay">
						<p class="christmas-music-setting-label"><?php echo __( 'Choose position of the button on your website', 'christmas-music' ); ?></p>
						<div class="christmas-music-position-setting">
							<div class="christmas-music-position-row">
								<label class="christmas-music-radio-setting">
									<input type="radio" name="xmasmusic_player_position" value="top-left" />
									<div></div>
								</label>
								<label class="christmas-music-radio-setting">
									<input type="radio" name="xmasmusic_player_position" value="top-right" />
									<div></div>
								</label>
							</div>
							<div class="christmas-music-position-row">
								<label class="christmas-music-radio-setting">
									<input type="radio" name="xmasmusic_player_position" value="bottom-left" />
									<div></div>
								</label>
								<label class="christmas-music-radio-setting">
									<input type="radio" name="xmasmusic_player_position" value="bottom-right" checked />
									<div></div>
								</label>
							</div>
						</div>
					</div>

					<div class="christmas-music-setting xmas-pro-overlay">
						<p class="christmas-music-setting-label"><?php echo __( 'Choose button style', 'christmas-music' ); ?></p>
						<div class="christmas-music-radio-group">
							<label class="christmas-music-radio-setting">
								<input type="radio" name="xmasmusic_player_style" value="circle" checked />
								<div></div>
								<span><?php echo __( 'Circle', 'christmas-music' ); ?></button>
							</label>
							<label class="christmas-music-radio-setting">
								<input type="radio" name="xmasmusic_player_style" value="square" />
								<div></div>
								<span><?php echo __( 'Square', 'christmas-music' ); ?></button>
							</label>
						</div>
					</div>

					<div class="christmas-music-setting xmas-pro-overlay">
						<label class="christmas-music-checkbox-setting">
							<input type="checkbox" name="xmasmusic_player_animation" value="true" />
							<div></div>
							<span><?php echo __( 'Add soft animation (pulse) to the button', 'christmas-music' ); ?></button>
						</label>
					</div>

					<div class="christmas-music-setting" style="max-width: 100%;">
						<label class="christmas-music-color-setting">
							<div><input type="text" name="button_bg" id="button_bg" value="<?php echo $button_background; ?>" data-default-color="#ff0000"/></div>
							<div class="christmas-music-setting-label"><?php echo __( 'Background color of the play/pause button', 'christmas-music' ); ?></div>
						</label>
						<label class="christmas-music-color-setting">
							<div><input type="text" name="button_color" id="button_color" value="<?php echo $icon_color; ?>" data-default-color="#ffffff"/></div>
							<div class="christmas-music-setting-label"><?php echo __( 'Icon color of the play/pause button', 'christmas-music' ); ?></div>
						</label>
					</div>
				</div>
				<hr>

				<div class="christmas-music-settings-footer">
					<?php submit_button( $text = null, $type = 'primary', $name = 'submit', $wrap = false, $other_attributes = null ); ?>
					<a class="christmas-music-settings-footer-pro-link" href="https://xmasmusicwp.com/" target="_blank">
					<?php echo __( 'Get PRO', 'christmas-music' ); ?>
						<img src="<?php echo XMAS_MUSIC_DIR_URL . 'admin/images/arrow-right.svg'; ?>" alt="icon" />
					</a>
				</div>
			</form>

		</div>

		<div class="christmas-music-settings-sidebar">
			<h3><?php echo __( 'Faq', 'christmas-music' ); ?></h3>
			<p><?php echo __( '1. You can find more info about this plugin', 'christmas-music' ); ?> <a href="https://wordpress.org/plugins/christmas-music/" target="_blank"><?php echo __( 'here', 'christmas-music' ); ?></a>.</p>
			<p><?php echo __( '2. If something doesn’t work or you’re stuck with the settings, don’t hesitate to submit your ticket', 'christmas-music' ); ?> <a href="https://wordpress.org/support/plugin/christmas-music/" target="_blank"><?php echo __( 'here', 'christmas-music' ); ?></a>.<br><?php echo __( 'We reply the same day.', 'christmas-music' ); ?></p>
			<h3><?php echo __( 'Notes', 'christmas-music' ); ?></h3>
			<p><?php echo __( 'Some browsers do not allow autoplay, it also differs for the different versions of the browsers. The strictest browser for our plugin is Mozilla Firefox, it doesn’t allow autoplay at all.<br>These browser terms change pretty often and randomly so we can’t always notice that instantly. Please bear with us.', 'christmas-music' ); ?></p>
			<p><?php echo __( 'However, we do our best to keep this plugin compatible with the browsers as much as possible.', 'christmas-music' ); ?></p>
			<h3><?php echo __( 'Pro version', 'christmas-music' ); ?></h3>
			<p>
			<?php
			echo __(
				'
				To unblock all the features marked as PRO currently, please consider using PRO version of this plugin.',
				'christmas-music'
			);
			?>
				<br>
				<a href="https://xmasmusicwp.com/" target="_blank"><?php echo __( 'Find more info here', 'christmas-music' ); ?></a>
			</p>
		</div>

	</div>
	
</div>
