/**
 * Public side scripts
 */

document.addEventListener('DOMContentLoaded', function () {
  var xmasMusicAudio = document.createElement('audio'),
      xmasMusicCurrentTime = Cookies.get('xmasMusicCurrentTime') || 0.0,
      xmasMusicPaused = Cookies.get('xmasMusicPaused') || '',
      playerClasses = [];

  /**
   * Audio settings
   */

  // Set audio current time
  xmasMusicAudio.currentTime = xmasMusicCurrentTime;

  // Enable audio loop
  xmasMusicAudio.setAttribute('loop', 'loop');

  // Audio file
  xmasMusicAudio.setAttribute('src', xmasMusicSettings.audioFileUrl);

  // Volume
  xmasMusicAudio.volume = 0.3;

  // Autoplay
  if (!xmasMusicPaused) {
    var promise = xmasMusicAudio.play();

    if (promise !== undefined) {
      promise.then(_ => {
        // Autoplay started!
      }).catch(error => {
        // Autoplay was prevented.
        if ( xmasMusicSettings.enableTooltip && !Cookies.get('xmasMusicTooltipClosed') ) {
          document.querySelector('.xmas-music-tooltip-wrapper').classList.add('tooltip-visible');
        }
      });
    }
  }

  /**
   * Audio events
   */
  xmasMusicAudio.addEventListener('playing', function () {
    document.getElementById('xmas-music-button').classList.add('plays');
    Cookies.set('xmasMusicPaused', '');
  });

  xmasMusicAudio.addEventListener('pause', function () {
    document.getElementById('xmas-music-button').classList.remove('plays');
  });

  window.addEventListener('beforeunload', function () {
    Cookies.set('xmasMusicCurrentTime', xmasMusicAudio.currentTime);
  });

  /**
   * Player markup
   */
  playerClasses = playerClasses.join(' ');
  
  document.body.insertAdjacentHTML(
    'beforeend',
    `<div id="xmas-music-player" class="${playerClasses}">
      <div class="xmas-music-tooltip-wrapper">
        <div class="xmas-music-tooltip"></div>
        <button class="xmas-music-tooltip-close" type="button"></button>
      </div>
      <button id="xmas-music-button" style="background: ${xmasMusicSettings.buttonBackground};" type="button">
        <span style="border-left-color: ${xmasMusicSettings.iconColor};"></span>
      </button>
     </div>`
  );

  /**
   * Player events
   */
  document.addEventListener('click', function (e) {
    var el = e.target;

    // Click on play/pause button
    if (el.id == 'xmas-music-button' || el.parentNode.id == 'xmas-music-button') {
      if (xmasMusicAudio.paused == false) {
        xmasMusicAudio.pause();
        Cookies.set('xmasMusicPaused', 'true');
      } else {
        xmasMusicAudio.play();
      }

    // Click on tooltip content
    } else if (el.classList.contains('xmas-music-tooltip')) {
      xmasMusicAudio.play();
      document.querySelector('.xmas-music-tooltip-wrapper').classList.remove('tooltip-visible');
    
    // Click on tooltip close button
    } else if (el.classList.contains('xmas-music-tooltip-close')) {
      document.querySelector('.xmas-music-tooltip-wrapper').classList.remove('tooltip-visible');
      Cookies.set('xmasMusicTooltipClosed', 'true');
    }
  });

  /**
   * Document events
   */
  document.addEventListener('visibilitychange', function() {
    if (document.visibilityState == 'visible') {
      xmasMusicAudio.currentTime = Cookies.get('xmasMusicCurrentTime') || 0.0;
      if (!Cookies.get('xmasMusicPaused')) {
        xmasMusicAudio.play();
      }
    } else {
      xmasMusicAudio.pause();
      Cookies.set('xmasMusicCurrentTime', xmasMusicAudio.currentTime);
    }
  });
});
